@@ -22,6 +22,7 @@
 #define GCONF_GCONF_VALUE_H
 
 #include <glib.h>
+#include <glib-object.h>
 #include "gconf-error.h"
 
 G_BEGIN_DECLS
@@ -76,6 +77,7 @@ GConfValue* gconf_value_new_from_string      (GConfValueType type,
                                               const gchar* str,
                                               GError** err);
 
+GType       gconf_value_get_type             (void) G_GNUC_CONST;
 GConfValue* gconf_value_copy                 (const GConfValue* src);
 void        gconf_value_free                 (GConfValue* value);
 
@@ -163,6 +165,7 @@ struct _GConfEntry {
   GConfValue *value;
 };
 
+GType       gconf_entry_get_type        (void) G_GNUC_CONST;
 const char* gconf_entry_get_key         (const GConfEntry *entry);
 GConfValue* gconf_entry_get_value       (const GConfEntry *entry);
 const char* gconf_entry_get_schema_name (const GConfEntry *entry);
